# pyiwenli

python 基础库

- python setup.py sdist
- twine upload --repository-url https://test.pypi.org/legacy/ dist/pyiwenli-0.0.7.tar.gz
- twine upload dist/pyiwenli-0.0.7.tar.gz

# 常用邮箱服务商的 `POP3` 和 `SMTP` 协议地址

| 服务商                            | pop3（默认服务端口：25） | smtp                            |
| --------------------------------- | ------------------------ | ------------------------------- |
| 新浪 VIP 邮箱                     | pop3.vip.sina.com        | smtp.vip.sina.com               |
| 新浪免费邮件                      | pop3.sina.com.cn         | smtp.sina.com.cn                |
| 新浪免费邮箱                      | pop.sina.com             | smtp.sina.com                   |
| 新浪企业邮箱                      | pop.sina.com             | smtp.sina.com                   |
| 163 邮箱 smtp 服务器              | pop.163.com              | smtp.163.com                    |
| QQ 邮箱 smtp 服务器及端口(仅 SSL) | imap.exmail.qq.com - 993 | smtp.exmail.qq.com - 465 或 587 |
| QQ 邮箱                           | pop.exmail.qq.com        | smtp.exmail.qq.com              |
| yahoo 邮箱                        | pop.mail.yahoo.com.cn    | smtp.mail.yahoo.com             |
| 雅虎邮箱                          | pop.mail.yahoo.cn        | smtp.mail.yahoo.cn              |
| 126 邮箱 smtp 服务器              | pop.126.com              | smtp.126.com                    |
| 搜狐邮箱                          | pop3.sohu.com            | smtp.sohu.com                   |
| TOM 邮箱                          | pop.tom.com              | smtp.tom.com                    |
| Gmail 邮箱                        | pop.gmail.com            | smtp.gmail.com - 587 或 25      |
| 263 邮箱 - 域名：263.net          | 263.net                  | smtp.263.net                    |
| 263 邮箱 - 域名：x263.net         | pop.x263.net             | smtp.x263.net                   |
| 263 邮箱 - 域名：263.net.cn       | 263.net.cn               | 263.net.cn                      |
| 263 邮箱 - 域名：炫我型           | pop.263xmail.com         | smtp.263xmail.com               |
| 21CN 免费邮箱                     | pop.21cn.com             | smtp.21cn.com                   |
| 21CN 经济邮邮箱                   | pop.21cn.com             | smtp.21cn.com                   |
| 21CN 商务邮邮箱                   | pop.21cn.net             | smtp.21cn.net                   |
| 21CN 快感邮箱                     | vip.21cn.com             | vip.21cn.com                    |
| 21CN Y 邮箱                       | pop.y.vip.21cn.com       | smtp.y.vip.21cn.com             |
| 中华网任我邮邮箱                  | rwpop.china.com          | rwsmtp.china.com                |
| 中华网时尚、商务邮箱              | pop.china.com            | smtp.china.com                  |
